==> dde-calendar_5.9.5.orig.tar.xz: dde-calendar-5.9.5/translations/dde-calendar-service_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Lavoro</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Personale</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Altro</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Un giorno prima di iniziare</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Ricordamelo domani</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Ricordamelo piu tardi</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>Dopo 15 minuti</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>Dopo 1 ora</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>Dopo 4 ore</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Domani</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Pianifica promemoria</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 a %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Oggi</translation>
    </message>
</context>
<context>
    <name>JobRemindManager</name>
    <message>
        <source>One day before start</source>
        <translation type="vanished">Un giorno prima dell&apos;inizio</translation>
    </message>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">Chiudi</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">Ricordamelo domani</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">Ricordamelo più tardi</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">Pianifica promemoria</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">dalle %1 alle %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">Oggi</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">Domani</translation>
    </message>
</context>
</TS>

==> dde-calendar_5.9.14.orig.tar.xz: dde-calendar-5.9.14/translations/dde-calendar-service_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Lavoro</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Personale</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Altro</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Un giorno prima di iniziare</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Ricordamelo domani</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Ricordamelo piu tardi</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>Dopo 15 minuti</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>Dopo 1 ora</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>Dopo 4 ore</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Domani</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Pianifica promemoria</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 a %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Oggi</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
